@@ -19,6 +19,10 @@ class bcolors:
 client = docker.from_env()
 container = client.containers.list(all=True, filters={'name':'jenkins'})
 
+CONTAINERSTATE=""
+PORT=""
+IMAGE=""
+
 for i in container:
     DATA = i.attrs
     IMAGE = str(i.image)
